@@ -29,10 +29,10 @@
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/EntityRightsFilterModel>
 #include <Akonadi/EntityTreeModel>
-#include <Akonadi/History>
 #include <Akonadi/ItemModifyJob>
 #include <Akonadi/ItemMoveJob>
 #include <Akonadi/Monitor>
+#include <Akonadi/History>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 #include <EventViews/Prefs>
@@ -310,7 +310,7 @@ void CalendarManager::refreshEnabledTodoCollections()
 
 bool CalendarManager::loading() const
 {
-    return !m_calendar->isLoaded();
+    return m_calendar->isLoading();
 }
 
 void CalendarManager::setCollectionSelectionProxyModel(KCheckableProxyModel *m)
